# skeltymlops

`skeltymlops` is a dummy Python package designed to demonstrate package structure and publishing on PyPI.

## Installation

You can install the package using:

```sh
pip install skeltymlops
